# *****************************************************************************
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Paul M. Neves <pmneves@mit.edu>
# *****************************************************************************

from frappy.core import Readable, Parameter, FloatRange, Module, Attached, Writable


class Temp(Writable):
    """a voltage output with loop"""

    value = Parameter(unit='K', value=0)
    target = Parameter('target voltage', FloatRange(0, 325, unit='K'),
                       readonly=False)

    def write_target(self, target):
        self.value = target


class Forwarder(Module):
    """forward the values of a module to the target of another module"""
    src = Attached(Readable, 'source module')
    dst = Attached(Writable, 'destination module')

    def initModule(self):
        super().initModule()
        self.src.registerCallbacks(self)

    def update_value(self, value):
        self.dst.write_target(value)
