# *****************************************************************************
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Markus Zolliker <markus.zolliker@psi.ch>
#   Leon Zimmermann <leon.zimmermann@psi.ch>
# *****************************************************************************
"""Powersupply TDK-Lambda GEN8-400-1P230"""

from frappy.core import StringIO, Readable, Parameter, FloatRange, Writable, HasIO, BoolType

class IO(StringIO):
    end_of_line = ('OK\r', '\r')
    default_settings = {'baudrate': 9600}

    
class Power(HasIO, Readable):
    value = Parameter(datatype=FloatRange(0,3300,unit='W'))
    
    def read_value(self):
        reply_volt = self.communicate('MV?')
        reply_current = self.communicate('MC?')
        volt = float(reply_volt)
        current = float(reply_current)
        return volt*current

    
class Output(HasIO, Writable):
    value = Parameter(datatype=FloatRange(0,100,unit='%'))
    target = Parameter(datatype=FloatRange(0,100,unit='%'))
    maxvolt = Parameter('voltage at 100%',datatype=FloatRange(0,8,unit='V'),readonly=False)
    maxcurrent = Parameter('current at 100%',datatype=FloatRange(0,400,unit='A'),readonly=False)
    output_enable = Parameter('control on/off', BoolType(), readonly=False)
    
    def initModule(self):
        super().initModule()
        self.write_output_enable(False)
        
    def write_target(self, target):
        self.write_output_enable(target != 0)
        self.communicate(f'PV {target*self.maxvolt:.5f}')
        self.communicate(f'PC {target*self.maxcurrent:.5f}')
        self.value = target
        
    def write_output_enable(self, value):
        self.communicate(f'OUT {int(value)}')
        
    def shutdown(self):
        self.write_target(0)
    
